Index: /applications/editors/josm/plugins/mapillary/src/org/openstreetmap/josm/plugins/mapillary/MapillaryAction.java
===================================================================
--- /applications/editors/josm/plugins/mapillary/src/org/openstreetmap/josm/plugins/mapillary/MapillaryAction.java	(revision 30949)
+++ /applications/editors/josm/plugins/mapillary/src/org/openstreetmap/josm/plugins/mapillary/MapillaryAction.java	(revision 30950)
@@ -2,5 +2,5 @@
  * 
  */
-package org.openstreetmap.josm.plugins.sumoconvert;
+package org.openstreetmap.josm.plugins.mapillary;
 
 import static org.openstreetmap.josm.tools.I18n.tr;
@@ -18,14 +18,14 @@
 
 /**
- * @author ignacio_palermo
+ * @author Polyglot
  *
  */
-public class SumoExportAction extends JosmAction {
+public class MapillaryAction extends JosmAction {
 	
-	public SumoExportAction(){
-        super(tr("OSM Export"), "images/dialogs/logo-sumo.png",
-        tr("Export traffic data to SUMO network file."),
-        Shortcut.registerShortcut("menu:sumoexport", tr("Menu: {0}", tr("SUMO Export")),
-        KeyEvent.VK_G, Shortcut.ALT_CTRL), false);
+	public MapillaryAction(){
+        super(tr("Mapillary"), "images/icon24.png",
+        tr("Create Mapillary layer."),
+        Shortcut.registerShortcut("menu:Mapillary", tr("Menu: {0}", tr("Mapillary")),
+        KeyEvent.VK_M, Shortcut.ALT_CTRL), false);
     }
 
@@ -35,5 +35,5 @@
 	@Override
 	public void actionPerformed(ActionEvent arg0) {
-		SumoExportDialog dialog = new SumoExportDialog();
+		MapillaryDialog dialog = new MapillaryDialog();
         JOptionPane pane = new JOptionPane(dialog, JOptionPane.PLAIN_MESSAGE, JOptionPane.OK_CANCEL_OPTION);
         JDialog dlg = pane.createDialog(Main.parent, tr("Export"));
@@ -41,6 +41,6 @@
         dlg.setVisible(true);
         if(((Integer)pane.getValue()) == JOptionPane.OK_OPTION){
-            ExportTask task = new ExportTask();
-            Main.worker.execute(task);
+            // MapillaryTask task = new MapillaryTask();
+            // Main.worker.execute(task);
         }
         dlg.dispose();
Index: /applications/editors/josm/plugins/mapillary/src/org/openstreetmap/josm/plugins/mapillary/MapillaryDialog.java
===================================================================
--- /applications/editors/josm/plugins/mapillary/src/org/openstreetmap/josm/plugins/mapillary/MapillaryDialog.java	(revision 30949)
+++ /applications/editors/josm/plugins/mapillary/src/org/openstreetmap/josm/plugins/mapillary/MapillaryDialog.java	(revision 30950)
@@ -2,5 +2,5 @@
  * 
  */
-package org.openstreetmap.josm.plugins.sumoconvert;
+package org.openstreetmap.josm.plugins.mapillary;
 
 import static org.openstreetmap.josm.tools.I18n.tr;
@@ -28,8 +28,8 @@
 /**
  * Main export dialog
- * @author ignacio_palermo
+ * @author Polyglot
  *
  */
-public class SumoExportDialog extends JPanel {
+public class MapillaryDialog extends JPanel {
 	// the JOptionPane that contains this dialog. required for the closeDialog() method.
     private JOptionPane optionPane;
@@ -38,5 +38,5 @@
     
 
-    public SumoExportDialog() {
+    public MapillaryDialog() {
         GridBagConstraints c = new GridBagConstraints();
         JButton refreshBtn, configBtn;
@@ -88,5 +88,5 @@
                         JOptionPane.showMessageDialog(Main.parent, tr("Connection Error.") + " " + ex.toString());
                     }
-                    System.out.println("configureing the device finised");
+                    System.out.println("configuring the device finished");
                 }
             });
Index: /applications/editors/josm/plugins/mapillary/src/org/openstreetmap/josm/plugins/mapillary/MapillaryPlugin.java
===================================================================
--- /applications/editors/josm/plugins/mapillary/src/org/openstreetmap/josm/plugins/mapillary/MapillaryPlugin.java	(revision 30949)
+++ /applications/editors/josm/plugins/mapillary/src/org/openstreetmap/josm/plugins/mapillary/MapillaryPlugin.java	(revision 30950)
@@ -1,3 +1,3 @@
-package org.openstreetmap.josm.plugins.sumoconvert;
+package org.openstreetmap.josm.plugins.mapillary;
 
 import java.util.ArrayList;
@@ -9,22 +9,13 @@
 import org.openstreetmap.josm.plugins.Plugin;
 import org.openstreetmap.josm.plugins.PluginInformation;
-import org.openstreetmap.josm.plugins.turnrestrictions.list.TurnRestrictionsListDialog;
-import org.openstreetmap.josm.plugins.turnrestrictions.preferences.PreferenceEditor;
-import org.openstreetmap.josm.plugins.turnrestrictions.*;
 
 /**
  * This is the main class for the sumoconvert plugin.
  * 
  */
-public class SumoConvertPlugin extends Plugin{
-    
-	private final ArrayList<Relation> turnrestrictions = new ArrayList<Relation>();
-	private SumoExportAction exportAction;
+public class MapillaryPlugin extends Plugin{
 	
-    public SumoConvertPlugin(PluginInformation info) {
+    public MapillaryPlugin(PluginInformation info) {
         super(info);
-        exportAction = new SumoExportAction();
-        Main.main.menu.toolsMenu.add(exportAction);
-        System.out.println(getPluginDir());
     }
     
@@ -36,14 +27,5 @@
         if (oldFrame == null && newFrame != null) { // map frame added
         	
-            //TurnRestrictionsListDialog dialog  = new TurnRestrictionsListDialog();
-            //add the dialog
-            //newFrame.addToggleDialog(dialog);
-            //CreateOrEditTurnRestrictionAction.getInstance();
         }
     }
-
-    @Override
-    public PreferenceSetting getPreferenceSetting() {
-        return new PreferenceEditor();
-    }
 }
@@ -9,22 +9,13 @@
 
 /**
- * This is the main class for the sumoconvert plugin.
+ * This is the main class for the mapillary plugin.
  * 
  */
